CE_NS

Struct CE_NS 

pub struct CE_NS { /* private fields */ }
Crypoto Engine

Implementations

Source

impl CE_NS

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn ce_tda(&self) -> &CE_TDA

0x00 - Task Descriptor Address

pub fn ce_icr(&self) -> &CE_ICR

0x08 - Interrupt Control Register

pub fn ce_isr(&self) -> &CE_ISR

0x0c - Interrupt Status Register

pub fn ce_tlr(&self) -> &CE_TLR

0x10 - Task Load Register

pub fn ce_tsr(&self) -> &CE_TSR

0x14 - Task Status Register

pub fn ce_esr(&self) -> &CE_ESR

0x18 - Error Status Register

pub fn ce_csa(&self) -> &CE_CSA

0x24 - Current Source Address Register

pub fn ce_cda(&self) -> &CE_CDA

0x28 - Current Destination Address Register

pub fn ce_tpr(&self) -> &CE_TPR

0x2c - Throughput Register