OWA

Struct OWA 

pub struct OWA { /* private fields */ }
One Wire Audio

Implementations

Source

impl OWA

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn owa_gen_ctl(&self) -> &OWA_GEN_CTL

0x00 - OWA General Control Register

pub fn owa_tx_cfig(&self) -> &OWA_TX_CFIG

0x04 - OWA TX Configuration Register

pub fn owa_rx_cfig(&self) -> &OWA_RX_CFIG

0x08 - OWA RX Configuration Register

pub fn owa_ista(&self) -> &OWA_ISTA

0x0c - OWA Interrupt Status Register

pub fn owa_rxfifo(&self) -> &OWA_RXFIFO

0x10 - OWA RXFIFO Register

pub fn owa_fctl(&self) -> &OWA_FCTL

0x14 - OWA FIFO Control Register

pub fn owa_fsta(&self) -> &OWA_FSTA

0x18 - OWA FIFO Status Register

pub fn owa_int(&self) -> &OWA_INT

0x1c - OWA Interrupt Control Register

pub fn owa_tx_fifo(&self) -> &OWA_TX_FIFO

0x20 - OWA TX FIFO Register

pub fn owa_tx_cnt(&self) -> &OWA_TX_CNT

0x24 - OWA TX Counter Register

pub fn owa_rx_cnt(&self) -> &OWA_RX_CNT

0x28 - OWA RX Counter Register

pub fn owa_tx_chsta0(&self) -> &OWA_TX_CHSTA0

0x2c - OWA TX Channel Status Register0

pub fn owa_tx_chsta1(&self) -> &OWA_TX_CHSTA1

0x30 - OWA TX Channel Status Register1

pub fn owa_rxchsta0(&self) -> &OWA_RXCHSTA0

0x34 - OWA RX Channel Status Register0

pub fn owa_rxchsta1(&self) -> &OWA_RXCHSTA1

0x38 - OWA RX Channel Status Register1

pub fn owa_exp_ctl(&self) -> &OWA_EXP_CTL

0x40 - OWA Expand Control Register

pub fn owa_exp_ista(&self) -> &OWA_EXP_ISTA

0x44 - OWA Expand Interrupt Status Register

pub fn owa_exp_info_0(&self) -> &OWA_EXP_INFO_0

0x48 - OWA Expand Infomation Register0

pub fn owa_exp_info_1(&self) -> &OWA_EXP_INFO_1

0x4c - OWA Expand Infomation Register1

pub fn owa_exp_dbg_0(&self) -> &OWA_EXP_DBG_0

0x50 - OWA Expand Debug Register0

pub fn owa_exp_dbg_1(&self) -> &OWA_EXP_DBG_1

0x54 - OWA Expand Debug Register1