TVD0

Struct TVD0 

pub struct TVD0 { /* private fields */ }
Television Decoder

Implementations

Source

impl TVD0

pub const PTR: *const RegisterBlock

Pointer to the register block

pub const fn ptr() -> *const RegisterBlock

Return the pointer to the register block

pub unsafe fn steal() -> Self

Steal an instance of this peripheral

Safety

Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.

Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.

Methods from Deref<Target = RegisterBlock>

pub fn tvd_en(&self) -> &TVD_EN

0x00 - TVD MODULE CONTROL Register

pub fn tvd_mode(&self) -> &TVD_MODE

0x04 - TVD MODE CONTROL Register

pub fn tvd_clamp_agc1(&self) -> &TVD_CLAMP_AGC1

0x08 - TVD CLAMP And AGC CONTROL Register1

pub fn tvd_clamp_agc2(&self) -> &TVD_CLAMP_AGC2

0x0c - TVD CLAMP And AGC CONTROL Register2

pub fn tvd_hlock1(&self) -> &TVD_HLOCK1

0x10 - TVD HLOCK CONTROL Register1

pub fn tvd_hlock2(&self) -> &TVD_HLOCK2

0x14 - TVD HLOCK CONTROL Register2

pub fn tvd_hlock3(&self) -> &TVD_HLOCK3

0x18 - TVD HLOCK CONTROL Register3

pub fn tvd_hlock4(&self) -> &TVD_HLOCK4

0x1c - TVD HLOCK CONTROL Register4

pub fn tvd_hlock5(&self) -> &TVD_HLOCK5

0x20 - TVD HLOCK CONTROL Register5

pub fn tvd_vlock1(&self) -> &TVD_VLOCK1

0x24 - TVD VLOCK CONTROL Register1

pub fn tvd_vlock2(&self) -> &TVD_VLOCK2

0x28 - TVD VLOCK CONTROL Register2

pub fn tvd_clock1(&self) -> &TVD_CLOCK1

0x30 - TVD CHROMA LOCK CONTROL Register1

pub fn tvd_clock2(&self) -> &TVD_CLOCK2

0x34 - TVD CHROMA LOCK CONTROL Register2

pub fn tvd_yc_sep1(&self) -> &TVD_YC_SEP1

0x40 - TVD YC SEPERATION CONROL Register1

pub fn tvd_yc_sep2(&self) -> &TVD_YC_SEP2

0x44 - TVD YC SEPERATION CONROL Register2

pub fn tvd_enhance1(&self) -> &TVD_ENHANCE1

0x50 - TVD ENHANCEMENT CONTROL Register1

pub fn tvd_enhance2(&self) -> &TVD_ENHANCE2

0x54 - TVD ENHANCEMENT CONTROL Register2

pub fn tvd_enhance3(&self) -> &TVD_ENHANCE3

0x58 - TVD ENHANCEMENT CONTROL Register3

pub fn tvd_wb1(&self) -> &TVD_WB1

0x60 - TVD WB DMA CONTROL Register1

pub fn tvd_wb2(&self) -> &TVD_WB2

0x64 - TVD WB DMA CONTROL Register2

pub fn tvd_wb3(&self) -> &TVD_WB3

0x68 - TVD WB DMA CONTROL Register3

pub fn tvd_wb4(&self) -> &TVD_WB4

0x6c - TVD WB DMA CONTROL Register4

pub fn tvd_irq_ctl(&self) -> &TVD_IRQ_CTL

0x80 - TVD DMA Interrupt Control Register

pub fn tvd_irq_status(&self) -> &TVD_IRQ_STATUS

0x90 - TVD DMA Interrupt Status Register

pub fn tvd_debug1(&self) -> &TVD_DEBUG1

0x100 - TVD DEBUG CONTROL Register1

pub fn tvd_status1(&self) -> &TVD_STATUS1

0x180 - TVD DEBUG STATUS Register1

pub fn tvd_status2(&self) -> &TVD_STATUS2

0x184 - TVD DEBUG STATUS Register2

pub fn tvd_status3(&self) -> &TVD_STATUS3

0x188 - TVD DEBUG STATUS Register3

pub fn tvd_status4(&self) -> &TVD_STATUS4

0x18c - TVD DEBUG STATUS Register4

pub fn tvd_status5(&self) -> &TVD_STATUS5

0x190 - TVD DEBUG STATUS Register5

pub fn tvd_status6(&self) -> &TVD_STATUS6

0x194 - TVD DEBUG STATUS Register6