pub struct CCU { /* private fields */ }Expand description
Clock Controller Unit
Implementations
Sourceimpl CCU
impl CCU
Sourcepub const PTR: *const RegisterBlock
pub const PTR: *const RegisterBlock
Pointer to the register block
Sourcepub const fn ptr() -> *const RegisterBlock
pub const fn ptr() -> *const RegisterBlock
Return the pointer to the register block
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Steal an instance of this peripheral
Safety
Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.
Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.
Methods from Deref<Target = RegisterBlock>
Sourcepub fn pll_cpu_ctrl(&self) -> &PLL_CPU_CTRL
pub fn pll_cpu_ctrl(&self) -> &PLL_CPU_CTRL
0x00 - PLL_CPU Control Register
Sourcepub fn pll_ddr_ctrl(&self) -> &PLL_DDR_CTRL
pub fn pll_ddr_ctrl(&self) -> &PLL_DDR_CTRL
0x10 - PLL_DDR Control Register
Sourcepub fn pll_peri_ctrl(&self) -> &PLL_PERI_CTRL
pub fn pll_peri_ctrl(&self) -> &PLL_PERI_CTRL
0x20 - PLL_PERI Control Register
Sourcepub fn pll_video0_ctrl(&self) -> &PLL_VIDEO0_CTRL
pub fn pll_video0_ctrl(&self) -> &PLL_VIDEO0_CTRL
0x40 - PLL_VIDEO0 Control Register
Sourcepub fn pll_video1_ctrl(&self) -> &PLL_VIDEO1_CTRL
pub fn pll_video1_ctrl(&self) -> &PLL_VIDEO1_CTRL
0x48 - PLL_VIDEO1 Control Register
Sourcepub fn pll_ve_ctrl(&self) -> &PLL_VE_CTRL
pub fn pll_ve_ctrl(&self) -> &PLL_VE_CTRL
0x58 - PLL_VE Control Register
Sourcepub fn pll_audio0_ctrl(&self) -> &PLL_AUDIO0_CTRL
pub fn pll_audio0_ctrl(&self) -> &PLL_AUDIO0_CTRL
0x78 - PLL_AUDIO0 Control Register
Sourcepub fn pll_audio1_ctrl(&self) -> &PLL_AUDIO1_CTRL
pub fn pll_audio1_ctrl(&self) -> &PLL_AUDIO1_CTRL
0x80 - PLL_AUDIO1 Control Register
Sourcepub fn pll_ddr_pat0_ctrl(&self) -> &PLL_DDR_PAT0_CTRL
pub fn pll_ddr_pat0_ctrl(&self) -> &PLL_DDR_PAT0_CTRL
0x110 - PLL_DDR Pattern0 Control Register
Sourcepub fn pll_ddr_pat1_ctrl(&self) -> &PLL_DDR_PAT1_CTRL
pub fn pll_ddr_pat1_ctrl(&self) -> &PLL_DDR_PAT1_CTRL
0x114 - PLL_DDR Pattern1 Control Register
Sourcepub fn pll_peri_pat0_ctrl(&self) -> &PLL_PERI_PAT0_CTRL
pub fn pll_peri_pat0_ctrl(&self) -> &PLL_PERI_PAT0_CTRL
0x120 - PLL_PERI Pattern0 Control Register
Sourcepub fn pll_peri_pat1_ctrl(&self) -> &PLL_PERI_PAT1_CTRL
pub fn pll_peri_pat1_ctrl(&self) -> &PLL_PERI_PAT1_CTRL
0x124 - PLL_PERI Pattern1 Control Register
Sourcepub fn pll_video0_pat0_ctrl(&self) -> &PLL_VIDEO0_PAT0_CTRL
pub fn pll_video0_pat0_ctrl(&self) -> &PLL_VIDEO0_PAT0_CTRL
0x140 - PLL_VIDEO0 Pattern0 Control Register
Sourcepub fn pll_video0_pat1_ctrl(&self) -> &PLL_VIDEO0_PAT1_CTRL
pub fn pll_video0_pat1_ctrl(&self) -> &PLL_VIDEO0_PAT1_CTRL
0x144 - PLL_VIDEO0 Pattern1 Control Register
Sourcepub fn pll_video1_pat0_ctrl(&self) -> &PLL_VIDEO1_PAT0_CTRL
pub fn pll_video1_pat0_ctrl(&self) -> &PLL_VIDEO1_PAT0_CTRL
0x148 - PLL_VIDEO1 Pattern0 Control Register
Sourcepub fn pll_video1_pat1_ctrl(&self) -> &PLL_VIDEO1_PAT1_CTRL
pub fn pll_video1_pat1_ctrl(&self) -> &PLL_VIDEO1_PAT1_CTRL
0x14c - PLL_VIDEO1 Pattern1 Control Register
Sourcepub fn pll_ve_pat0_ctrl(&self) -> &PLL_VE_PAT0_CTRL
pub fn pll_ve_pat0_ctrl(&self) -> &PLL_VE_PAT0_CTRL
0x158 - PLL_VE Pattern0 Control Register
Sourcepub fn pll_ve_pat1_ctrl(&self) -> &PLL_VE_PAT1_CTRL
pub fn pll_ve_pat1_ctrl(&self) -> &PLL_VE_PAT1_CTRL
0x15c - PLL_VE Pattern1 Control Register
Sourcepub fn pll_audio0_pat0_ctrl(&self) -> &PLL_AUDIO0_PAT0_CTRL
pub fn pll_audio0_pat0_ctrl(&self) -> &PLL_AUDIO0_PAT0_CTRL
0x178 - PLL_AUDIO0 Pattern0 Control Register
Sourcepub fn pll_audio0_pat1_ctrl(&self) -> &PLL_AUDIO0_PAT1_CTRL
pub fn pll_audio0_pat1_ctrl(&self) -> &PLL_AUDIO0_PAT1_CTRL
0x17c - PLL_AUDIO0 Pattern1 Control Register
Sourcepub fn pll_audio1_pat0_ctrl(&self) -> &PLL_AUDIO1_PAT0_CTRL
pub fn pll_audio1_pat0_ctrl(&self) -> &PLL_AUDIO1_PAT0_CTRL
0x180 - PLL_AUDIO1 Pattern0 Control Register
Sourcepub fn pll_audio1_pat1_ctrl(&self) -> &PLL_AUDIO1_PAT1_CTRL
pub fn pll_audio1_pat1_ctrl(&self) -> &PLL_AUDIO1_PAT1_CTRL
0x184 - PLL_AUDIO1 Pattern1 Control Register
Sourcepub fn pll_cpu_bias(&self) -> &PLL_CPU_BIAS
pub fn pll_cpu_bias(&self) -> &PLL_CPU_BIAS
0x300 - PLL_CPU Bias Register
Sourcepub fn pll_ddr_bias(&self) -> &PLL_DDR_BIAS
pub fn pll_ddr_bias(&self) -> &PLL_DDR_BIAS
0x310 - PLL_DDR Bias Register
Sourcepub fn pll_peri_bias(&self) -> &PLL_PERI_BIAS
pub fn pll_peri_bias(&self) -> &PLL_PERI_BIAS
0x320 - PLL_PERI Bias Register
Sourcepub fn pll_video0_bias(&self) -> &PLL_VIDEO0_BIAS
pub fn pll_video0_bias(&self) -> &PLL_VIDEO0_BIAS
0x340 - PLL_VIDEO0 Bias Register
Sourcepub fn pll_video1_bias(&self) -> &PLL_VIDEO1_BIAS
pub fn pll_video1_bias(&self) -> &PLL_VIDEO1_BIAS
0x348 - PLL_VIDEO1 Bias Register
Sourcepub fn pll_ve_bias(&self) -> &PLL_VE_BIAS
pub fn pll_ve_bias(&self) -> &PLL_VE_BIAS
0x358 - PLL_VE Bias Register
Sourcepub fn pll_audio0_bias(&self) -> &PLL_AUDIO0_BIAS
pub fn pll_audio0_bias(&self) -> &PLL_AUDIO0_BIAS
0x378 - PLL_AUDIO0 Bias Register
Sourcepub fn pll_audio1_bias(&self) -> &PLL_AUDIO1_BIAS
pub fn pll_audio1_bias(&self) -> &PLL_AUDIO1_BIAS
0x380 - PLL_AUDIO1 Bias Register
Sourcepub fn pll_cpu_tun(&self) -> &PLL_CPU_TUN
pub fn pll_cpu_tun(&self) -> &PLL_CPU_TUN
0x400 - PLL_CPU Tuning Register
Sourcepub fn cpu_axi_cfg(&self) -> &CPU_AXI_CFG
pub fn cpu_axi_cfg(&self) -> &CPU_AXI_CFG
0x500 - CPU_AXI Configuration Register
Sourcepub fn cpu_gating(&self) -> &CPU_GATING
pub fn cpu_gating(&self) -> &CPU_GATING
0x504 - CPU_GATING Configuration Register
Sourcepub fn msgbox_bgr(&self) -> &MSGBOX_BGR
pub fn msgbox_bgr(&self) -> &MSGBOX_BGR
0x71c - MSGBOX Bus Gating Reset Register
Sourcepub fn spinlock_bgr(&self) -> &SPINLOCK_BGR
pub fn spinlock_bgr(&self) -> &SPINLOCK_BGR
0x72c - SPINLOCK Bus Gating Reset Register
Sourcepub fn hstimer_bgr(&self) -> &HSTIMER_BGR
pub fn hstimer_bgr(&self) -> &HSTIMER_BGR
0x73c - HSTIMER Bus Gating Reset Register
Sourcepub fn dbgsys_bgr(&self) -> &DBGSYS_BGR
pub fn dbgsys_bgr(&self) -> &DBGSYS_BGR
0x78c - DBGSYS Bus Gating Reset Register
Sourcepub fn mbus_mat_clk_gating(&self) -> &MBUS_MAT_CLK_GATING
pub fn mbus_mat_clk_gating(&self) -> &MBUS_MAT_CLK_GATING
0x804 - MBUS Master Clock Gating Register
Sourcepub fn emac_25m_clk(&self) -> &EMAC_25M_CLK
pub fn emac_25m_clk(&self) -> &EMAC_25M_CLK
0x970 - EMAC_25M Clock Register
Sourcepub fn i2s2_asrc_clk(&self) -> &I2S2_ASRC_CLK
pub fn i2s2_asrc_clk(&self) -> &I2S2_ASRC_CLK
0xa1c - I2S2_ASRC Clock Register
Sourcepub fn owa_tx_clk(&self) -> &OWA_TX_CLK
pub fn owa_tx_clk(&self) -> &OWA_TX_CLK
0xa24 - OWA_TX Clock Register
Sourcepub fn owa_rx_clk(&self) -> &OWA_RX_CLK
pub fn owa_rx_clk(&self) -> &OWA_RX_CLK
0xa28 - OWA_RX Clock Register
Sourcepub fn audio_codec_dac_clk(&self) -> &AUDIO_CODEC_DAC_CLK
pub fn audio_codec_dac_clk(&self) -> &AUDIO_CODEC_DAC_CLK
0xa50 - AUDIO_CODEC_DAC Clock Register
Sourcepub fn audio_codec_adc_clk(&self) -> &AUDIO_CODEC_ADC_CLK
pub fn audio_codec_adc_clk(&self) -> &AUDIO_CODEC_ADC_CLK
0xa54 - AUDIO_CODEC_ADC Clock Register
Sourcepub fn audio_codec_bgr(&self) -> &AUDIO_CODEC_BGR
pub fn audio_codec_bgr(&self) -> &AUDIO_CODEC_BGR
0xa5c - AUDIO_CODEC Bus Gating Reset Register
Sourcepub fn dpss_top_bgr(&self) -> &DPSS_TOP_BGR
pub fn dpss_top_bgr(&self) -> &DPSS_TOP_BGR
0xabc - DPSS_TOP Bus Gating Reset Register
Sourcepub fn tconlcd_clk(&self) -> &TCONLCD_CLK
pub fn tconlcd_clk(&self) -> &TCONLCD_CLK
0xb60 - TCONLCD Clock Register
Sourcepub fn tconlcd_bgr(&self) -> &TCONLCD_BGR
pub fn tconlcd_bgr(&self) -> &TCONLCD_BGR
0xb7c - TCONLCD Bus Gating Reset Register
Sourcepub fn tcontv_clk(&self) -> &TCONTV_CLK
pub fn tcontv_clk(&self) -> &TCONTV_CLK
0xb80 - TCONTV Clock Register
Sourcepub fn tcontv_bgr(&self) -> &TCONTV_BGR
pub fn tcontv_bgr(&self) -> &TCONTV_BGR
0xb9c - TCONTV Bus Gating Reset Register
Sourcepub fn csi_master_clk(&self) -> &CSI_MASTER_CLK
pub fn csi_master_clk(&self) -> &CSI_MASTER_CLK
0xc08 - CSI Master Clock Register
Sourcepub fn riscv_gating(&self) -> &RISCV_GATING
pub fn riscv_gating(&self) -> &RISCV_GATING
0xd04 - RISC-V GATING Configuration Register
Sourcepub fn riscv_cfg_bgr(&self) -> &RISCV_CFG_BGR
pub fn riscv_cfg_bgr(&self) -> &RISCV_CFG_BGR
0xd0c - RISC-V_CFG Bus Gating Reset Register
Sourcepub fn pll_lock_dbg_ctrl(&self) -> &PLL_LOCK_DBG_CTRL
pub fn pll_lock_dbg_ctrl(&self) -> &PLL_LOCK_DBG_CTRL
0xf04 - PLL Lock Debug Control Register
Sourcepub fn fre_det_ctrl(&self) -> &FRE_DET_CTRL
pub fn fre_det_ctrl(&self) -> &FRE_DET_CTRL
0xf08 - Frequency Detect Control Register
Sourcepub fn fre_up_lim(&self) -> &FRE_UP_LIM
pub fn fre_up_lim(&self) -> &FRE_UP_LIM
0xf0c - Frequency Up Limit Register
Sourcepub fn fre_down_lim(&self) -> &FRE_DOWN_LIM
pub fn fre_down_lim(&self) -> &FRE_DOWN_LIM
0xf10 - Frequency Down Limit Register
Sourcepub fn ccu_fan_gate(&self) -> &CCU_FAN_GATE
pub fn ccu_fan_gate(&self) -> &CCU_FAN_GATE
0xf30 - CCU FANOUT CLOCK GATE Register
Sourcepub fn clk27m_fan(&self) -> &CLK27M_FAN
pub fn clk27m_fan(&self) -> &CLK27M_FAN
0xf34 - CLK27M FANOUT Register