pub struct HS_TIMER { /* private fields */ }Expand description
High Speed Timer
Implementations
Sourceimpl HS_TIMER
impl HS_TIMER
Sourcepub const PTR: *const RegisterBlock
pub const PTR: *const RegisterBlock
Pointer to the register block
Sourcepub const fn ptr() -> *const RegisterBlock
pub const fn ptr() -> *const RegisterBlock
Return the pointer to the register block
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Steal an instance of this peripheral
Safety
Ensure that the new instance of the peripheral cannot be used in a way that may race with any existing instances, for example by only accessing read-only or write-only registers, or by consuming the original peripheral and using critical sections to coordinate access between multiple new instances.
Additionally, other software such as HALs may rely on only one peripheral instance existing to ensure memory safety; ensure no stolen instances are passed to such software.
Methods from Deref<Target = RegisterBlock>
Sourcepub fn hs_tmr_irq_en(&self) -> &HS_TMR_IRQ_EN
pub fn hs_tmr_irq_en(&self) -> &HS_TMR_IRQ_EN
0x00 - HS Timer IRQ Enable Register
Sourcepub fn hs_tmr_irq_stas(&self) -> &HS_TMR_IRQ_STAS
pub fn hs_tmr_irq_stas(&self) -> &HS_TMR_IRQ_STAS
0x04 - HS Timer Status Register
Sourcepub fn hs_tmr_ctrl(&self, n: usize) -> &HS_TMR_CTRL
pub fn hs_tmr_ctrl(&self, n: usize) -> &HS_TMR_CTRL
0x20..0x28 - HS Timer Control Register
Sourcepub fn hs_tmr0_ctrl(&self) -> &HS_TMR_CTRL
pub fn hs_tmr0_ctrl(&self) -> &HS_TMR_CTRL
0x20 - HS Timer Control Register
Sourcepub fn hs_tmr1_ctrl(&self) -> &HS_TMR_CTRL
pub fn hs_tmr1_ctrl(&self) -> &HS_TMR_CTRL
0x40 - HS Timer Control Register
Sourcepub fn hs_tmr_intv_lo(&self, n: usize) -> &HS_TMR_INTV_LO
pub fn hs_tmr_intv_lo(&self, n: usize) -> &HS_TMR_INTV_LO
0x24..0x2c - HS Timer Interval Value Low Register
Sourcepub fn hs_tmr0_intv_lo(&self) -> &HS_TMR_INTV_LO
pub fn hs_tmr0_intv_lo(&self) -> &HS_TMR_INTV_LO
0x24 - HS Timer Interval Value Low Register
Sourcepub fn hs_tmr1_intv_lo(&self) -> &HS_TMR_INTV_LO
pub fn hs_tmr1_intv_lo(&self) -> &HS_TMR_INTV_LO
0x44 - HS Timer Interval Value Low Register
Sourcepub fn hs_tmr_intv_hi(&self, n: usize) -> &HS_TMR_INTV_HI
pub fn hs_tmr_intv_hi(&self, n: usize) -> &HS_TMR_INTV_HI
0x28..0x30 - HS Timer Interval Value High Register
Sourcepub fn hs_tmr0_intv_hi(&self) -> &HS_TMR_INTV_HI
pub fn hs_tmr0_intv_hi(&self) -> &HS_TMR_INTV_HI
0x28 - HS Timer Interval Value High Register
Sourcepub fn hs_tmr1_intv_hi(&self) -> &HS_TMR_INTV_HI
pub fn hs_tmr1_intv_hi(&self) -> &HS_TMR_INTV_HI
0x48 - HS Timer Interval Value High Register
Sourcepub fn hs_tmr_curnt_lo(&self, n: usize) -> &HS_TMR_CURNT_LO
pub fn hs_tmr_curnt_lo(&self, n: usize) -> &HS_TMR_CURNT_LO
0x2c..0x34 - HS Timer Current Value Low Register
Sourcepub fn hs_tmr0_curnt_lo(&self) -> &HS_TMR_CURNT_LO
pub fn hs_tmr0_curnt_lo(&self) -> &HS_TMR_CURNT_LO
0x2c - HS Timer Current Value Low Register
Sourcepub fn hs_tmr1_curnt_lo(&self) -> &HS_TMR_CURNT_LO
pub fn hs_tmr1_curnt_lo(&self) -> &HS_TMR_CURNT_LO
0x4c - HS Timer Current Value Low Register
Sourcepub fn hs_tmr_curnt_hi(&self, n: usize) -> &HS_TMR_CURNT_HI
pub fn hs_tmr_curnt_hi(&self, n: usize) -> &HS_TMR_CURNT_HI
0x30..0x38 - HS Timer Current Value High Register
Sourcepub fn hs_tmr0_curnt_hi(&self) -> &HS_TMR_CURNT_HI
pub fn hs_tmr0_curnt_hi(&self) -> &HS_TMR_CURNT_HI
0x30 - HS Timer Current Value High Register
Sourcepub fn hs_tmr1_curnt_hi(&self) -> &HS_TMR_CURNT_HI
pub fn hs_tmr1_curnt_hi(&self) -> &HS_TMR_CURNT_HI
0x50 - HS Timer Current Value High Register